==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/uk-UA/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Аксесуар встановлено в',
    'Accessory_Checkout_Notification' => 'Аксесуар перевірено',
    'Asset_Checkin_Notification' => 'Актив перевірений',
    'Asset_Checkout_Notification' => 'Актив перевірено',
    'Confirm_Accessory_Checkin' => 'Підтвердити реєстрацію аксесуара.',
    'Confirm_Asset_Checkin' => 'Підтвердити реєстрацію активів.',
    'Confirm_accessory_delivery' => 'Підтвердьте доставку аксесуара.',
    'Confirm_asset_delivery' => 'Підтвердьте доставку активу.',
    'Confirm_consumable_delivery' => 'Підтвердження доставки витратних матеріалів.',
    'Confirm_license_delivery' => 'Підтвердження доставки ліцензії',
    'Consumable_checkout_notification' => 'Витратний перевірений',
    'Days' => 'Днів',
    'Expected_Checkin_Date' => 'Медіафайл не відмічений вам через перевірку в :date',
    'Expected_Checkin_Notification' => 'Нагадування: завершується термін перевірки імені',
    'Expected_Checkin_Report' => 'Очікуваний звіт про перевірку активів',
    'Expiring_Assets_Report' => 'Звіт про активи з завершенням терміну придатності.',
    'Expiring_Licenses_Report' => 'Звіт про ліцензії з завершеням терміну придатності.',
    'Item_Request_Canceled' => 'Запит скасовано',
    'Item_Requested' => 'Запит на',
    'License_Checkin_Notification' => 'Ліцензія перевірена',
    'License_Checkout_Notification' => 'Ліцензію перевірено',
    'Low_Inventory_Report' => 'Звіт про низький рівень інвентарю',
    'a_user_canceled' => 'Користувач скасував запит на об\'єкт на веб-сайті',
    'a_user_requested' => 'Користувач надіслав запит на об\'єкт на веб-сайті',
    'acceptance_asset_accepted' => 'Користувач прийняв позицію',
    'acceptance_asset_declined' => 'Користувач відхилив елемент',
    'accessory_name' => 'Назва аксесуара',
    'additional_notes' => 'Додаткові примітки',
    'admin_has_created' => 'Адміністратор створив вам обліковий запис на веб-сайті.',
    'asset' => 'Актив',
    'asset_name' => 'Назва активу',
    'asset_requested' => 'Запит на актив',
    'asset_tag' => 'Тег активу',
    'assets_warrantee_alert' => 'В наступні :threshold днів є :count медіафайл з гарантією, яка закінчується в наступні :threshold днів.|В наступних :threshold медіафайлів з гарантіями, що закінчуються в наступні :threshold днів.',
    'assigned_to' => 'Відповідальний',
    'best_regards' => 'З найкращими побажаннями,',
    'canceled' => 'Скасовано',
    'checkin_date' => 'Дата повернення',
    'checkout_date' => 'Дата видачі',
    'checkedout_from' => 'Перевірено з',
    'checkedin_from'  => 'Відмічено від',
    'checked_into' => 'Відмічено від',
    'click_on_the_link_accessory' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали аксесуар.',
    'click_on_the_link_asset' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали актив.',
    'click_to_confirm' => 'Будь-ласка, натисніть на це посилання, щоб підтвердити свій: веб-акаунт:',
    'current_QTY' => 'Поточна к-ксть',
    'days' => 'Днів',
    'expecting_checkin_date' => 'Очікувана дата повернення',
    'expires' => 'Термін закінчується',
    'hello' => 'Привіт',
    'hi' => 'Привіт',
    'i_have_read' => 'Я прочитав і згоден з умовами використання даного товару.',
    'inventory_report' => 'Звіт про запаси',
    'item' => 'Елемент',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'В наступні :threshold днів закінчується :count термін дії ліцензії для наступних :threshold днів.|В наступному :threshold строк дії ліцензії.',
    'link_to_update_password' => 'Будь-ласка, натисніть на це посилання, щоб оновити свій пароль:',
    'login' => 'Логін:',
    'login_first_admin' => 'Увійдіть до вашої нової установки Snipe-IT за допомогою нижче:',
    'low_inventory_alert' => 'Є :count елемент, який нижчий мінімальний інвентар або низький. Є :count предмети, які нижче мінімального інвентарю, або скоро будуть низькими.',
    'min_QTY' => 'Мін. кількість',
    'name' => 'Назва',
    'new_item_checked' => 'Новий елемент був виданий під вашим ім\'ям, докладніше про це нижче.',
    'notes' => 'Примітки.',
    'password' => 'Пароль',
    'password_reset' => 'Скидання Пароля',
    'read_the_terms' => 'Будь ласка, прочитайте умови використання нижче.',
    'read_the_terms_and_click' => 'Будь ласка, прочитайте умови використання нижче, і натисніть на посилання внизу, щоб підтвердити, що Ви прочитали та згодні з умовами користування та отримали актив.',
    'requested' => 'Запрошено користувачем',
    'reset_link' => 'Ваше посилання для скидання пароля',
    'reset_password' => 'Натисніть тут для скидання пароля:',
    'rights_reserved' => 'Усі права захищені.',
    'serial' => 'Серійний номер',
    'snipe_webhook_test' => 'Тест інтеграції Snipe-IT',
    'snipe_webhook_summary' => 'Підсумок інтеграції Snipe-IT',
    'supplier' => 'Постачальник',
    'tag' => 'Тег',
    'test_email' => 'Тестовий електронний лист зі Snipe-IT',
    'test_mail_text' => 'Це тест з системи управління активами Snipe-IT. Якщо ви отримали, пошта працює :)',
    'the_following_item' => 'Наступний товар перевірено в: ',
    'to_reset' => 'Щоб скинути :web пароль, завершіть цю форму:',
    'type' => 'Тип',
    'upcoming-audits' => 'Знайдено :count актив, що наближається до аудиту в :threshold днів.|Є :count активів, які йдуть до аудиту в :threshold днів.',
    'user' => 'Користувач',
    'username' => 'Ім\'я кристувача',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Ласкаво просимо, :name',
    'welcome_to' => 'Ласкаво просимо до :web!',
    'your_assets' => 'Переглянути Ваші Активи',
    'your_credentials' => 'Ваші облікові дані Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/uk-UA/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Аксесуар встановлено в',
    'Accessory_Checkout_Notification' => 'Аксесуар перевірено',
    'Asset_Checkin_Notification' => 'Актив перевірений',
    'Asset_Checkout_Notification' => 'Актив перевірено',
    'Confirm_Accessory_Checkin' => 'Підтвердити реєстрацію аксесуара.',
    'Confirm_Asset_Checkin' => 'Підтвердити реєстрацію активів.',
    'Confirm_accessory_delivery' => 'Підтвердьте доставку аксесуара.',
    'Confirm_asset_delivery' => 'Підтвердьте доставку активу.',
    'Confirm_consumable_delivery' => 'Підтвердження доставки витратних матеріалів.',
    'Confirm_license_delivery' => 'Підтвердження доставки ліцензії',
    'Consumable_checkout_notification' => 'Витратний перевірений',
    'Days' => 'Днів',
    'Expected_Checkin_Date' => 'Медіафайл не відмічений вам через перевірку в :date',
    'Expected_Checkin_Notification' => 'Нагадування: завершується термін перевірки імені',
    'Expected_Checkin_Report' => 'Очікуваний звіт про перевірку активів',
    'Expiring_Assets_Report' => 'Звіт про активи з завершенням терміну придатності.',
    'Expiring_Licenses_Report' => 'Звіт про ліцензії з завершеням терміну придатності.',
    'Item_Request_Canceled' => 'Запит скасовано',
    'Item_Requested' => 'Запит на',
    'License_Checkin_Notification' => 'Ліцензія перевірена',
    'License_Checkout_Notification' => 'Ліцензію перевірено',
    'license_for'   => 'Ліцензія для',
    'Low_Inventory_Report' => 'Звіт про низький рівень інвентарю',
    'a_user_canceled' => 'Користувач скасував запит на об\'єкт на веб-сайті',
    'a_user_requested' => 'Користувач надіслав запит на об\'єкт на веб-сайті',
    'acceptance_asset_accepted' => 'Користувач прийняв позицію',
    'acceptance_asset_declined' => 'Користувач відхилив елемент',
    'accessory_name' => 'Назва аксесуара',
    'additional_notes' => 'Додаткові примітки',
    'admin_has_created' => 'Адміністратор створив вам обліковий запис на веб-сайті.',
    'asset' => 'Актив',
    'asset_name' => 'Назва активу',
    'asset_requested' => 'Запит на актив',
    'asset_tag' => 'Тег активу',
    'assets_warrantee_alert' => 'В наступні :threshold днів є :count медіафайл з гарантією, яка закінчується в наступні :threshold днів.|В наступних :threshold медіафайлів з гарантіями, що закінчуються в наступні :threshold днів.',
    'assigned_to' => 'Відповідальний',
    'best_regards' => 'З найкращими побажаннями,',
    'canceled' => 'Скасовано',
    'checkin_date' => 'Дата повернення',
    'checkout_date' => 'Дата видачі',
    'checkedout_from' => 'Перевірено з',
    'checkedin_from'  => 'Відмічено від',
    'checked_into' => 'Відмічено від',
    'click_on_the_link_accessory' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали аксесуар.',
    'click_on_the_link_asset' => 'Будь ласка, натисніть на посилання внизу, щоб підтвердити, що Ви отримали актив.',
    'click_to_confirm' => 'Будь-ласка, натисніть на це посилання, щоб підтвердити свій: веб-акаунт:',
    'current_QTY' => 'Поточна к-ксть',
    'days' => 'Днів',
    'expecting_checkin_date' => 'Очікувана дата повернення',
    'expires' => 'Термін закінчується',
    'hello' => 'Привіт',
    'hi' => 'Привіт',
    'i_have_read' => 'Я прочитав і згоден з умовами використання даного товару.',
    'inventory_report' => 'Звіт про запаси',
    'item' => 'Елемент',
    'item_checked_reminder' => 'Нагадуємо, що у вас є :count активів що видані вам, але не що не були підтверджені вами або відхилені. Будь ласка, натисніть на посилання нижче, щоб підтвердити своє рішення.',
    'license_expiring_alert' => 'В наступні :threshold днів закінчується :count термін дії ліцензії для наступних :threshold днів.|В наступному :threshold строк дії ліцензії.',
    'link_to_update_password' => 'Будь-ласка, натисніть на це посилання, щоб оновити свій пароль:',
    'login' => 'Вхід',
    'login_first_admin' => 'Увійдіть до вашої нової установки Snipe-IT за допомогою нижче:',
    'low_inventory_alert' => 'Є :count елемент, який нижчий мінімальний інвентар або низький. Є :count предмети, які нижче мінімального інвентарю, або скоро будуть низькими.',
    'min_QTY' => 'Мін. кількість',
    'name' => 'Назва',
    'new_item_checked' => 'Новий елемент був виданий під вашим ім\'ям, докладніше про це нижче.',
    'notes' => 'Примітки.',
    'password' => 'Пароль',
    'password_reset' => 'Скидання Пароля',
    'read_the_terms' => 'Будь ласка, прочитайте умови використання нижче.',
    'read_the_terms_and_click' => 'Будь ласка, прочитайте умови використання нижче, і натисніть на посилання внизу, щоб підтвердити, що Ви прочитали та згодні з умовами користування та отримали актив.',
    'requested' => 'Запрошено користувачем',
    'reset_link' => 'Ваше посилання для скидання пароля',
    'reset_password' => 'Натисніть тут для скидання пароля:',
    'rights_reserved' => 'Усі права захищені.',
    'serial' => 'Серійний номер',
    'snipe_webhook_test' => 'Тест інтеграції Snipe-IT',
    'snipe_webhook_summary' => 'Підсумок інтеграції Snipe-IT',
    'supplier' => 'Постачальник',
    'tag' => 'Тег',
    'test_email' => 'Тестовий електронний лист зі Snipe-IT',
    'test_mail_text' => 'Це тест з системи управління активами Snipe-IT. Якщо ви отримали, пошта працює :)',
    'the_following_item' => 'Наступний товар перевірено в: ',
    'to_reset' => 'Щоб скинути :web пароль, завершіть цю форму:',
    'type' => 'Тип',
    'upcoming-audits' => 'Знайдено :count актив, що наближається до аудиту в :threshold днів.|Є :count активів, які йдуть до аудиту в :threshold днів.',
    'user' => 'Користувач',
    'username' => 'Ім\'я кристувача',
    'unaccepted_asset_reminder' => 'Ви не підтвердили отримання Активів.',
    'welcome' => 'Ласкаво просимо, :name',
    'welcome_to' => 'Ласкаво просимо до :web!',
    'your_assets' => 'Переглянути Ваші Активи',
    'your_credentials' => 'Ваші облікові дані Snipe-IT',
    'mail_sent' => 'Повідомлення успішно відправлено!',
];
